@@ -257,9 +257,7 @@ STREAMING_OPEN_MAX_RETRIES = 20
 STREAMING_OPEN_RETRY_INTERVAL = 5
 
 # Datasets repositories exploration
-DATA_FILES_MAX_NUMBER_FOR_MODULE_INFERENCE = 200
-GLOBBED_DATA_FILES_MAX_NUMBER_FOR_MODULE_INFERENCE = 10
-ARCHIVED_DATA_FILES_MAX_NUMBER_FOR_MODULE_INFERENCE = 200
+ARCHIVES_MAX_NUMBER_FOR_MODULE_INFERENCE = 10
 
 # Async map functions
 MAX_NUM_RUNNING_ASYNC_MAP_FUNCTIONS_IN_PARALLEL = 1000
