@@ -124,7 +124,7 @@ if config.DILL_VERSION < version.parse("0.3.6"):
     def log(pickler, msg):
         dill._dill.log.info(msg)
 
-elif _is_supported_dill_version():
+else:
 
     def log(pickler, msg):
         dill._dill.logger.trace(pickler, msg)
@@ -317,7 +317,7 @@ if config.DILL_VERSION < version.parse("0.3.6"):
         dill._dill.log.info("# Co")
         return
 
-elif _is_supported_dill_version():
+else:
     # From: https://github.com/uqfoundation/dill/blob/dill-0.3.6/dill/_dill.py#L1104
     @pklregister(CodeType)
     def save_code(pickler, obj):
